@@ -16,15 +16,16 @@
 pub mod external;
 // pub mod public_channel;
 pub mod static_;
-// pub mod user;
+pub mod user;
 
 // #[doc(inline)]
 // pub use conversation::Conversation;
+
 #[doc(inline)]
 pub use external::External;
 // #[doc(inline)]
 // pub use public_channel::PublicChannel;
 #[doc(inline)]
 pub use static_::Static;
-// #[doc(inline)]
-// pub use user::User;
+#[doc(inline)]
+pub use user::User;
